==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALocalVariable.h <==
// public final class soot.jimple.parser.node.ALocalVariable

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3449fc4fc073a9ad soot_jimple_parser_node_ALocalVariable
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c929bf55a24d32c2 soot_jimple_parser_node_PVariable

// header file dependencies
// @dep_header soot_jimple_parser_node_PVariable

#include "soot/jimple/parser/node/PVariable.h"

#ifndef _JC_soot_jimple_parser_node_ALocalVariable_H_
#define _JC_soot_jimple_parser_node_ALocalVariable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PLocalName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$sub_refs	_jc_soot_jimple_parser_node_ALocalVariable$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs	_jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$refs	_jc_soot_jimple_parser_node_ALocalVariable$refs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$nonrefs	_jc_soot_jimple_parser_node_ALocalVariable$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$object	_jc_soot_jimple_parser_node_ALocalVariable$object;

typedef const struct _jc_soot_jimple_parser_node_ALocalVariable$vmethods	_jc_soot_jimple_parser_node_ALocalVariable$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALocalVariable$vtable	_jc_soot_jimple_parser_node_ALocalVariable$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALocalVariable$vtype	_jc_soot_jimple_parser_node_ALocalVariable$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *);
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$_init$e17ded02c1f5a7bc(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALocalVariable$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *);
extern struct _jc_soot_jimple_parser_node_PLocalName$object *_jc_soot_jimple_parser_node_ALocalVariable$method$getLocalName$6abeca666d69d27d(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *);
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$setLocalName$e0082a9faf2824c3(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALocalVariable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$getLocalName$6abeca666d69d27d;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$setLocalName$e0082a9faf2824c3;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALocalVariable$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *);
	struct _jc_soot_jimple_parser_node_PLocalName$object	*(*getLocalName$6abeca666d69d27d)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setLocalName$e0082a9faf2824c3)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALocalVariable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PVariable$vmethods	soot_jimple_parser_node_PVariable;
	_jc_soot_jimple_parser_node_ALocalVariable$vmethods	soot_jimple_parser_node_ALocalVariable;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALocalVariable$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALocalVariable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalVariable$sub_refs {
	struct _jc_soot_jimple_parser_node_PLocalName$object	*__5flocalName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalVariable$refs {
    _jc_soot_jimple_parser_node_ALocalVariable$sub_refs	soot_jimple_parser_node_ALocalVariable;
    _jc_soot_jimple_parser_node_PVariable$sub_refs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalVariable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PVariable$sub_nonrefs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs	soot_jimple_parser_node_ALocalVariable;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALocalVariable$object {
	_jc_soot_jimple_parser_node_ALocalVariable$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALocalVariable$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALocalVariable$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALocalVariable$vtype _jc_soot_jimple_parser_node_ALocalVariable$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALocalVariable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALocalVariable$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALocalVariable_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALocalVariable.h <==
// public final class soot.jimple.parser.node.ALocalVariable

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3449fc4fc073a9ad soot_jimple_parser_node_ALocalVariable
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c929bf55a24d32c2 soot_jimple_parser_node_PVariable

// header file dependencies
// @dep_header soot_jimple_parser_node_PVariable

#include "soot/jimple/parser/node/PVariable.h"

#ifndef _JC_soot_jimple_parser_node_ALocalVariable_H_
#define _JC_soot_jimple_parser_node_ALocalVariable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PLocalName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$sub_refs	_jc_soot_jimple_parser_node_ALocalVariable$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs	_jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$refs	_jc_soot_jimple_parser_node_ALocalVariable$refs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$nonrefs	_jc_soot_jimple_parser_node_ALocalVariable$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalVariable$object	_jc_soot_jimple_parser_node_ALocalVariable$object;

typedef const struct _jc_soot_jimple_parser_node_ALocalVariable$vmethods	_jc_soot_jimple_parser_node_ALocalVariable$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALocalVariable$vtable	_jc_soot_jimple_parser_node_ALocalVariable$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALocalVariable$vtype	_jc_soot_jimple_parser_node_ALocalVariable$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$_init$e17ded02c1f5a7bc(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALocalVariable$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PLocalName$object *_jc_soot_jimple_parser_node_ALocalVariable$method$getLocalName$6abeca666d69d27d(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalVariable$method$setLocalName$e0082a9faf2824c3(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALocalVariable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$getLocalName$6abeca666d69d27d;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$setLocalName$e0082a9faf2824c3;
extern _jc_method _jc_soot_jimple_parser_node_ALocalVariable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALocalVariable$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PLocalName$object	*(*getLocalName$6abeca666d69d27d)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setLocalName$e0082a9faf2824c3)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalVariable$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALocalVariable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PVariable$vmethods	soot_jimple_parser_node_PVariable;
	_jc_soot_jimple_parser_node_ALocalVariable$vmethods	soot_jimple_parser_node_ALocalVariable;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALocalVariable$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALocalVariable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalVariable$sub_refs {
	struct _jc_soot_jimple_parser_node_PLocalName$object	*__5flocalName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalVariable$refs {
    _jc_soot_jimple_parser_node_ALocalVariable$sub_refs	soot_jimple_parser_node_ALocalVariable;
    _jc_soot_jimple_parser_node_PVariable$sub_refs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalVariable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PVariable$sub_nonrefs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_ALocalVariable$sub_nonrefs	soot_jimple_parser_node_ALocalVariable;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALocalVariable$object {
	_jc_soot_jimple_parser_node_ALocalVariable$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALocalVariable$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALocalVariable$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALocalVariable$vtype _jc_soot_jimple_parser_node_ALocalVariable$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALocalVariable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALocalVariable$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALocalVariable_H_ */
